summaryrefslogtreecommitdiffstats
path: root/kio/kio/connection.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/connection.cpp')
-rw-r--r--kio/kio/connection.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/kio/connection.cpp b/kio/kio/connection.cpp
index b2a84a798..d85f4921c 100644
--- a/kio/kio/connection.cpp
+++ b/kio/kio/connection.cpp
@@ -43,7 +43,7 @@
#include <kdebug.h>
#include <tqsocketnotifier.h>
-using namespace KIO;
+using namespace TDEIO;
Connection::Connection()
{
@@ -83,7 +83,7 @@ void Connection::close()
delete socket;
socket = 0;
// KSocket has already closed the file descriptor, but we need to
// close the file-stream as well otherwise we leak memory.
// As a result we close the file descriptor twice, but that should
// be harmless
@@ -121,7 +121,7 @@ void Connection::dequeue()
}
}
-void Connection::init(KSocket *sock)
+void Connection::init(TDESocket *sock)
{
delete notifier;
notifier = 0;
@@ -83,7 +83,7 @@ void Connection::close()
delete socket;
socket = 0;
- // KSocket has already closed the file descriptor, but we need to
+ // TDESocket has already closed the file descriptor, but we need to
// close the file-stream as well otherwise we leak memory.
// As a result we close the file descriptor twice, but that should